NetworkException class

Exception thrown when there is a network-level failure.

Inheritance

Constructors

NetworkException(String message, [Object? originalError])
Creates a new NetworkException instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message describing the exception.
finalinherited
originalError Object?
The underlying cause of the exception, if any.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited