EnvironmentService class
A service for fetching environmental data (e.g. forest fire records) from data.gov.gr.
Constructors
- EnvironmentService(DataGovClient _client)
- Creates a new EnvironmentService instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getForestFires(
{DateTime? from, DateTime? to}) → Future< List< ForestFire> > - Fetches forest fire records, optionally filtered by a date range.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited