VaccinationData class
Represents daily and cumulative COVID-19 vaccination statistics for a specific area in Greece.
- Annotations
-
- @freezed
Constructors
- VaccinationData({required String area, @JsonKey.new(name: 'areaid') required int areaId, @JsonKey.new(name: 'dailydose1') required int dailyDose1, @JsonKey.new(name: 'dailydose2') required int dailyDose2, @JsonKey.new(name: 'dailydose3') required int? dailyDose3, @JsonKey.new(name: 'dailydose4') required int? dailyDose4, @JsonKey.new(name: 'daydiff') required int dayDiff, @JsonKey.new(name: 'daytotal') required int dayTotal, @JsonKey.new(name: 'referencedate') required DateTime referenceDate, @JsonKey.new(name: 'totaldose1') required int totalDose1, @JsonKey.new(name: 'totaldose2') required int totalDose2, @JsonKey.new(name: 'totaldose3') required int? totalDose3, @JsonKey.new(name: 'totaldose4') required int? totalDose4, @JsonKey.new(name: 'totaldistinctpersons') required int? totalDistinctPersons, @JsonKey.new(name: 'totalvaccinations') required int totalVaccinations})
-
Creates a new VaccinationData instance.
constfactory
-
VaccinationData.fromJson(Map<
String, dynamic> json) -
Creates a VaccinationData from a JSON map.
factory
Properties
- area → String
-
no setterinherited
- areaId → int
-
no setterinherited
-
copyWith
→ $VaccinationDataCopyWith<
VaccinationData> -
Create a copy of VaccinationData
with the given fields replaced by the non-null parameter values.
no setterinherited
- dailyDose1 → int
-
no setterinherited
- dailyDose2 → int
-
no setterinherited
- dailyDose3 → int?
-
no setterinherited
- dailyDose4 → int?
-
no setterinherited
- dayDiff → int
-
no setterinherited
- dayTotal → int
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- referenceDate → DateTime
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDistinctPersons → int?
-
no setterinherited
- totalDose1 → int
-
no setterinherited
- totalDose2 → int
-
no setterinherited
- totalDose3 → int?
-
no setterinherited
- totalDose4 → int?
-
no setterinherited
- totalVaccinations → int
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this VaccinationData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited